aboutsummaryrefslogtreecommitdiffstats
path: root/asn1
diff options
context:
space:
mode:
authorStig Bjørlykke <stig@bjorlykke.org>2015-08-11 14:08:08 +0200
committerStig Bjørlykke <stig@bjorlykke.org>2015-08-11 12:09:07 +0000
commitecc4f756bdb6175cc0b3b11af2f90884db1c602c (patch)
tree99d8ca48a72752e1257d4b8b321f41d1767ee020 /asn1
parent70d06deb2e31bd605e672200a7755764febe94ae (diff)
Added Reload Lua plugins.
This is initial support for reloading Lua plugins without restarting the application. Still todo: - Deregister FileHandlers - Support deregister ProtoField with existing abbrev (same_name_hfinfo) - Add a progress dialog when reloading many plugins - Search for memory leakages in wslua functions Change-Id: I48870d8741251705ca15ffe1068613fcb0cb18c1 Reviewed-on: https://code.wireshark.org/review/5028 Reviewed-by: Stig Bjørlykke <stig@bjorlykke.org>
Diffstat (limited to 'asn1')
-rw-r--r--asn1/ldap/packet-ldap-template.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/asn1/ldap/packet-ldap-template.c b/asn1/ldap/packet-ldap-template.c
index 7e4b823db9..eff9506ff7 100644
--- a/asn1/ldap/packet-ldap-template.c
+++ b/asn1/ldap/packet-ldap-template.c
@@ -557,9 +557,9 @@ attribute_types_initialize_cb(void)
if (attribute_types_hash && hf) {
guint hf_size = g_hash_table_size (attribute_types_hash);
/* Unregister all fields */
for (i = 0; i < hf_size; i++) {
- proto_unregister_field (proto_ldap, *(hf[i].p_id));
+ proto_deregister_field (proto_ldap, *(hf[i].p_id));
g_free (hf[i].p_id);
}
g_hash_table_destroy (attribute_types_hash);
@@ -557,9 +557,9 @@ attribute_types_initialize_cb(void)
if (attribute_types_hash && hf) {
guint hf_size = g_hash_table_size (attribute_types_hash);
- /* Unregister all fields */
+ /* Deregister all fields */
for (i = 0; i < hf_size; i++) {